rgbcore

Enum VerificationError

pub enum VerificationError<Seal: RgbSeal> {
    NoCodexCommitment,
    NoWitness(Opid),
    SealsNotClosed(<Seal::PubWitness as PublishedWitness<Seal>>::PubId, Opid, SealError<Seal>),
    SealUnknown(CellAddr),
    SealsDefinitionMismatch(Opid),
    Vm(CallError),
}

Variants



NoCodexCommitment

genesis does not commit to the codex id; a wrong contract genesis is used.



NoWitness(Opid)

no witness known for the operation {0}.



SealsNotClosed(<Seal::PubWitness as PublishedWitness<Seal>>::PubId, Opid, SealError<Seal>)

single-use seals are not closed properly with witness {0} for operation {1}.

Details: {2}



SealUnknown(CellAddr)

unknown seal definition for cell address {0}.



SealsDefinitionMismatch(Opid)

seals, reported to be defined by the operation {0}, do match the assignments in the operation.



Vm(CallError)